<?php

namespace Drupal\static_node\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\static_node\Service\StaticNodeHooks;

/**
 * Form for confirming static homepage deletion.
 */
class StaticHomepageDeleteForm extends ConfirmFormBase {

  /**
   * The static node service.
   *
   * @var \Drupal\static_node\Service\StaticNodeHooks
   */
  protected $staticNodeService;

  /**
   * Constructs a new StaticHomepageDeleteForm.
   *
   * @param \Drupal\static_node\Service\StaticNodeHooks $static_node_service
   *   The static node service.
   */
  public function __construct(StaticNodeHooks $static_node_service) {
    $this->staticNodeService = $static_node_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('static_node.hooks')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_node_homepage_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the static homepage file?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('static_node.files_management');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This will remove the static HTML version of the homepage, and anonymous users will see the dynamic version instead.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete Static Homepage');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->staticNodeService->deleteStaticHomepage();
    $form_state->setRedirectUrl(new Url('static_node.files_management'));
  }
}
